# Apply Templates

The Panel `Template` component is a special layout object that helps make deployable apps look nicer. These How-to pages provide solutions for common tasks related to using templates.

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`play;2.5em;sd-mr-1 sd-animate-grow50` Set a Template
:link: template_set
:link-type: doc

How to set a template for a deployable app.
:::

:::{grid-item-card} {octicon}`columns;2.5em;sd-mr-1 sd-animate-grow50` Arrange Components in a Template
:link: template_arrange
:link-type: doc

How to arrange components in a template layout.
:::

:::{grid-item-card} {octicon}`eye;2.5em;sd-mr-1 sd-animate-grow50` Toggle Modal
:link: template_modal
:link-type: doc

How to toggle the modal area of a template.
:::

:::{grid-item-card} {octicon}`paintbrush;2.5em;sd-mr-1 sd-animate-grow50` Customize Template Theme
:link: template_theme
:link-type: doc

How to customize the theme of a template.
:::

:::{grid-item-card} {octicon}`beaker;2.5em;sd-mr-1 sd-animate-grow50` Build a Custom Template
:link: template_custom
:link-type: doc

How to build a custom template.
:::

::::


```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2

template_set
template_arrange
template_modal
template_theme
template_custom
```
